@@ -513,7 +513,7 @@ check_for_users (void)
 		if (strcmp (rvec[0], gdmcomm_get_display ()) != 0 &&
 		    vt >= 0) {
 			/* this is not the current display */
-			extra ++;
+			extra++;
 		}
 
 		g_strfreev (rvec);
@@ -713,7 +713,8 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gtk_init(&argc, &argv);
+	/* Option parsing */
+
 	ctx = poptGetContext(NULL, argc, (const char**)argv, options, 0);
 	while ((nextopt = poptGetNextOpt(ctx)) > 0 || nextopt == POPT_ERROR_BADOPT);
 
@@ -732,6 +733,8 @@ main (int argc, char *argv[])
 		return 1;
 	}
 
+	/* Process --command option */
+
 	if (send_command != NULL) {
 		if (authenticate)
 			auth_cookie = gdmcomm_get_auth_cookie ();
@@ -751,9 +754,13 @@ main (int argc, char *argv[])
 				value = gdm_config_get_translated_string ((gchar *)key);
 				if (value != NULL) {
 					ret = g_strdup_printf ("OK %s", value);
-					g_free (value);
 				}
 			}
+
+			/*
+			 * If the above didn't return a value, then must be a
+			 * different key, so call gdmcomm_call_gdm.
+			 */
 			if (value == NULL)
 				ret = gdmcomm_call_gdm (send_command, auth_cookie,
 							"2.2.4.0", 5);
@@ -762,6 +769,9 @@ main (int argc, char *argv[])
 						"2.2.4.0", 5);
 		}
 
+		/* At this point we are done using the socket, so close it */
+		gdmcomm_comm_close ();
+
 		if (ret != NULL) {
 			g_print ("%s\n", ret);
 			return 0;
@@ -782,6 +792,24 @@ main (int argc, char *argv[])
 		}
 	}
 
+	/*
+	 * The --command argument does not display anything, so avoid running 
+	 * gtk_init until it finishes.  Sometimes the --command argument is
+	 * used when there is no display so it will fail and cause the 
+	 * program to exit, complaining about "no display".  
+	 *
+	 * Now process what gdmflexiserver is more used to do, start a
+	 * VT virtual terminal sesions - at least on systems where it
+	 * works.  On systems where it doesn't work VT stands for
+	 * "Very Tight" and will mess up your display if you try to
+	 * use it.  Tight!  So don't use it.  I'd accept a patch to
+	 * disable it, but its easy to avoid not using it as long
+	 * as your distro doesn't put the menu choice in the 
+	 * application launch button on the panel (don't ship the
+	 * desktop file).
+	 */
+	gtk_init(&argc, &argv);
+
 	/* always attempt to get cookie and authenticate.  On remote
 	servers */
 	auth_cookie = gdmcomm_get_auth_cookie ();
@@ -792,6 +820,9 @@ main (int argc, char *argv[])
 	if (use_xnest) {
 		char *cookie = gdmcomm_get_a_cookie (FALSE /* binary */);
 		if (cookie == NULL) {
+			/* At this point we are done using the socket, so close it */
+			gdmcomm_comm_close ();
+
 			dialog = ve_hig_dialog_new
 				(NULL /* parent */,
 				 GTK_DIALOG_MODAL /* flags */,
@@ -818,6 +849,9 @@ main (int argc, char *argv[])
 		auth_cookie = NULL;
 	} else {
 		if (auth_cookie == NULL) {
+			/* At this point we are done using the socket, so close it */
+			gdmcomm_comm_close ();
+
 			dialog = ve_hig_dialog_new
 				(NULL /* parent */,
 				 GTK_DIALOG_MODAL /* flags */,
@@ -848,6 +882,9 @@ main (int argc, char *argv[])
 	ret = gdmcomm_call_gdm (command, auth_cookie, version, 5);
 	g_free (command);
 
+	/* At this point we are done using the socket, so close it */
+	gdmcomm_comm_close ();
+
 	if (ret != NULL &&
 	    strncmp (ret, "OK ", 3) == 0) {
 
@@ -910,7 +947,7 @@ torture (void)
 		int len = rand () % 5000;
 		char *buf = g_new (char, len);
 		int ii;
-		for (ii = 0; ii < len; ii ++)
+		for (ii = 0; ii < len; ii++)
 			buf[ii] = rand () % 256;
 		write (fd, buf, len); 
 		g_free (buf);
@@ -927,7 +964,7 @@ torture_test (void)
 
 	srand (getpid () * time (NULL));
 
-	for (i = 0; i < 500; i ++) {
+	for (i = 0; i < 500; i++) {
 		if (fork () == 0) {
 			torture ();
 			_exit (0);
