@@ -23,9 +23,7 @@
 
 gint      greeter_language_get_save_language (void);
 gchar    *greeter_language_get_language      (const char      *old_language);
-void      greeter_action_language            (GreeterItemInfo *info,
-					      gpointer         user_data);
-
+void      greeter_language_handler           (void);
 
 #endif
 
